@@ -185,6 +185,7 @@ class BaseDAO:
     def create(self, payload):
         self.validate_arguments(payload)
         instance = self.model(**payload)
+        instance.id = None
         return DataBuffer(self.save(instance), instance.schema(), instance.fields(), False)
 
     def save(self, instance):
@@ -222,7 +223,7 @@ class BaseDAO:
 
         instance = self.get_one(instance_id, flagged=True).view()
         if instance is None or instance.active == 'D':
-            raise ValueError('This entry does not exist or maybe have been marked for deletion.')
+            raise ValueError('This entry does not exist or maybe has been marked for deletion.')
         instance.active = 'D'
         instance.save()
         return instance
